@@ -38,7 +38,7 @@ class CanonicalException(Exception):
         self.message = message or self.message
         self.detail = detail or self.detail
         self.hint = hint or self.hint
-        self.http_status_code = None
+        self.http_status_code = http_status_code or self.http_status_code
         self.schema = self.schema_class()
 
     def as_dict(self):
